@@ -302,6 +302,96 @@
         self.domainEventCallbackID[ret] = opaque
         return ret
 
+    def _dispatchStoragePoolEventLifecycleCallback(self, pool, event, detail, cbData):
+        """Dispatches events to python user storage pool
+           lifecycle event callbacks
+        """
+        cb = cbData["cb"]
+        opaque = cbData["opaque"]
+
+        cb(self, virStoragePool(self, _obj=pool), event, detail, opaque)
+        return 0
+
+    def _dispatchStoragePoolEventGenericCallback(self, pool, cbData):
+        """Dispatches events to python user storage pool
+           generic event callbacks
+        """
+        cb = cbData["cb"]
+        opaque = cbData["opaque"]
+
+        cb(self, virStoragePool(self, _obj=pool), opaque)
+        return 0
+
+    def storagePoolEventDeregisterAny(self, callbackID):
+        """Removes a Storage Pool Event Callback. De-registering for a
+           storage pool callback will disable delivery of this event type"""
+        try:
+            ret = libvirtmod.virConnectStoragePoolEventDeregisterAny(self._o, callbackID)
+            if ret == -1: raise libvirtError ('virConnectStoragePoolEventDeregisterAny() failed', conn=self)
+            del self.storagePoolEventCallbackID[callbackID]
+        except AttributeError:
+            pass
+
+    def storagePoolEventRegisterAny(self, pool, eventID, cb, opaque):
+        """Adds a Storage Pool Event Callback. Registering for a storage pool
+           callback will enable delivery of the events"""
+        if not hasattr(self, 'storagePoolEventCallbackID'):
+            self.storagePoolEventCallbackID = {}
+        cbData = { "cb": cb, "conn": self, "opaque": opaque }
+        if pool is None:
+            ret = libvirtmod.virConnectStoragePoolEventRegisterAny(self._o, None, eventID, cbData)
+        else:
+            ret = libvirtmod.virConnectStoragePoolEventRegisterAny(self._o, pool._o, eventID, cbData)
+        if ret == -1:
+            raise libvirtError ('virConnectStoragePoolEventRegisterAny() failed', conn=self)
+        self.storagePoolEventCallbackID[ret] = opaque
+        return ret
+
+    def _dispatchNodeDeviceEventLifecycleCallback(self, dev, event, detail, cbData):
+        """Dispatches events to python user node device
+           lifecycle event callbacks
+        """
+        cb = cbData["cb"]
+        opaque = cbData["opaque"]
+
+        cb(self, virNodeDevice(self, _obj=dev), event, detail, opaque)
+        return 0
+
+    def _dispatchNodeDeviceEventGenericCallback(self, dev, cbData):
+        """Dispatches events to python user node device
+           generic event callbacks
+        """
+        cb = cbData["cb"]
+        opaque = cbData["opaque"]
+
+        cb(self, virNodeDevice(self, _obj=dev), opaque)
+        return 0
+
+    def nodeDeviceEventDeregisterAny(self, callbackID):
+        """Removes a Node Device Event Callback. De-registering for a
+           node device callback will disable delivery of this event type"""
+        try:
+            ret = libvirtmod.virConnectNodeDeviceEventDeregisterAny(self._o, callbackID)
+            if ret == -1: raise libvirtError ('virConnectNodeDeviceEventDeregisterAny() failed', conn=self)
+            del self.nodeDeviceEventCallbackID[callbackID]
+        except AttributeError:
+            pass
+
+    def nodeDeviceEventRegisterAny(self, dev, eventID, cb, opaque):
+        """Adds a Node Device Event Callback. Registering for a node device
+           callback will enable delivery of the events"""
+        if not hasattr(self, 'nodeDeviceEventCallbackID'):
+            self.nodeDeviceEventCallbackID = {}
+        cbData = { "cb": cb, "conn": self, "opaque": opaque }
+        if dev is None:
+            ret = libvirtmod.virConnectNodeDeviceEventRegisterAny(self._o, None, eventID, cbData)
+        else:
+            ret = libvirtmod.virConnectNodeDeviceEventRegisterAny(self._o, dev._o, eventID, cbData)
+        if ret == -1:
+            raise libvirtError ('virConnectNodeDeviceEventRegisterAny() failed', conn=self)
+        self.nodeDeviceEventCallbackID[ret] = opaque
+        return ret
+
     def listAllDomains(self, flags=0):
         """List all domains and returns a list of domain objects"""
         ret = libvirtmod.virConnectListAllDomains(self._o, flags)
