@@ -173,6 +173,12 @@ for cname in wantfunctions:
         continue
     if name[0:22] == "virConnectNetworkEvent" and name[-8:] == "Callback":
         continue
+    if (name.startswith("virConnectStoragePoolEvent") and
+        name.endswith("Callback")):
+        continue
+    if (name.startswith("virConnectNodeDeviceEvent") and
+        name.endswith("Callback")):
+        continue
 
 
     # virEvent APIs go into main 'libvirt' namespace not any class
